@@ -1,10 +1,12 @@
 package Finance::DST::FAN::Mail::File::NFA;
 
-our $VERSION = '0.001000';
+our $VERSION = '0.002000';
 
 use Moose;
 extends 'Finance::DST::FAN::Mail::File::Activity';
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__;
@@ -22,13 +24,9 @@ For Usage information please refer to L<Finance::DST::FAN::Mail::File>.
 
 L<Finance::DST::FAN::Mail::File>, L<Finance::DST::FAN::Mail::Utils>
 
-=head1 AUTHOR
+=head1 AUTHOR & LICENSE
 
-Guillermo Roditi (groditi) <groditi@cpan.org>
-
-=head1 LICENSE
-
-You may distribute this code under the same terms as Perl itself.
+Please see L<Finance::DST::FAN::Mail> for more information.
 
 =cut
 
